Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(403)

Unified Diff: chrome/browser/resources/quota_internals/message_dispatcher.js

Issue 7084024: Add chrome://quota-internals/ (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: fix clang compile error Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/quota_internals/message_dispatcher.js
diff --git a/chrome/browser/resources/quota_internals/message_dispatcher.js b/chrome/browser/resources/quota_internals/message_dispatcher.js
index 37e5e94ad3c4779929988b3a7a4c7351deb75378..88646bacc02dbcc38ca9fca20c4c6081da8a4a96 100644
--- a/chrome/browser/resources/quota_internals/message_dispatcher.js
+++ b/chrome/browser/resources/quota_internals/message_dispatcher.js
@@ -18,25 +18,25 @@ cr.define('cr.quota', function() {
'use strict';
/**
* Post requestData message to Browser.
*/
- function requestData() {
- chrome.send('requestData');
+ function requestInfo() {
+ chrome.send('requestInfo');
}
/**
* Callback entry point from Browser.
* Messages are Dispatched as Event to:
* * onAvailableSpaceUpdated,
- * * onGlobalDataUpdated,
- * * onHostDataUpdated,
- * * onOriginDataUpdated,
+ * * onGlobalInfoUpdated,
+ * * onPerHostInfoUpdated,
+ * * onPerOriginInfoUpdated,
* * onStatisticsUpdated.
* @param {string} message Message label. Possible Values are:
* * 'AvailableSpaceUpdated',
- * * 'GlobalDataUpdated',
- * * 'HostDataUpdated',
- * * 'OriginDataUpdated',
+ * * 'GlobalInfoUpdated',
+ * * 'PerHostInfoUpdated',
+ * * 'PerOriginInfoUpdated',
* * 'StatisticsUpdated'.
* @param {Object} detail Message specific additional data.
*/
@@ -46,14 +46,14 @@ cr.define('cr.quota', function() {
case 'AvailableSpaceUpdated':
target = cr.quota.onAvailableSpaceUpdated;
break;
- case 'GlobalDataUpdated':
- target = cr.quota.onGlobalDataUpdated;
+ case 'GlobalInfoUpdated':
+ target = cr.quota.onGlobalInfoUpdated;
break;
- case 'HostDataUpdated':
- target = cr.quota.onHostDataUpdated;
+ case 'PerHostInfoUpdated':
+ target = cr.quota.onPerHostInfoUpdated;
break;
- case 'OriginDataUpdated':
- target = cr.quota.onOriginDataUpdated;
+ case 'PerOriginInfoUpdated':
+ target = cr.quota.onPerOriginInfoUpdated;
break;
case 'StatisticsUpdated':
target = cr.quota.onStatisticsUpdated;
@@ -71,12 +71,12 @@ cr.define('cr.quota', function() {
return {
onAvailableSpaceUpdated: new cr.EventTarget(),
- onGlobalDataUpdated: new cr.EventTarget(),
- onHostDataUpdated: new cr.EventTarget(),
- onOriginDataUpdated: new cr.EventTarget(),
+ onGlobalInfoUpdated: new cr.EventTarget(),
+ onPerHostInfoUpdated: new cr.EventTarget(),
+ onPerOriginInfoUpdated: new cr.EventTarget(),
onStatisticsUpdated: new cr.EventTarget(),
- requestData: requestData,
+ requestInfo: requestInfo,
messageHandler: messageHandler
};
});
@@ -18,25 +18,25 @@ cr.define('cr.quota', function() {
'use strict';
/**
- * Post requestData message to Browser.
+ * Post requestInfo message to Browser.
*/
« no previous file with comments | « chrome/browser/resources/quota_internals/event_handler.js ('k') | chrome/browser/ui/webui/quota_internals_handler.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698